==> dbservice-1.0.0-20141203.080503-1-sources.jar: com/xunlei/channel/db/pojo/ChannelAutoPayQuit.java <==
/**
 * 
 */
package com.xunlei.channel.db.pojo;

import java.util.Date;

/**
 * 渠道自动续费退订表
 * 
 * @author gonglijian
 */
public class ChannelAutoPayQuit extends AbstractBaseEntity {

    /**
	 * 
	 */
    private static final long serialVersionUID = -1190682736820312898L;
    private String            xunleiId;
    private String            userShow;
    private String            xunlei_pay_id;
    private String            phone;
    /**
     * 退订类型
     */
    private String            quitType;
    /**
     * 退订状态：W：等待;S:退订成功;F：退订失败
     */
    private String            status;

    private String            payType;
    private String            bizOrderId;
    private String            bizNo;
    private Integer           orderAmt;
    private Date              reqTime;
    private Date              cancelTime;
    private String            extraJson;

    /**
     * @return the xunleiId
     */
    public String getXunleiId() {
        return xunleiId;
    }

    /**
     * @param xunleiId the xunleiId to set
     */
    public void setXunleiId(String xunleiId) {
        this.xunleiId = xunleiId;
    }

    /**
     * @return the userShow
     */
    public String getUserShow() {
        return userShow;
    }

    /**
     * @param userShow the userShow to set
     */
    public void setUserShow(String userShow) {
        this.userShow = userShow;
    }

    /**
     * @return the xunlei_pay_id
     */
    public String getXunlei_pay_id() {
        return xunlei_pay_id;
    }

    /**
     * @param xunlei_pay_id the xunlei_pay_id to set
     */
    public void setXunlei_pay_id(String xunlei_pay_id) {
        this.xunlei_pay_id = xunlei_pay_id;
    }

    /**
     * @return the phone
     */
    public String getPhone() {
        return phone;
    }

    /**
     * @param phone the phone to set
     */
    public void setPhone(String phone) {
        this.phone = phone;
    }

    /**
     * @return the quitType
     */
    public String getQuitType() {
        return quitType;
    }

    /**
     * @param quitType the quitType to set
     */
    public void setQuitType(String quitType) {
        this.quitType = quitType;
    }

    /**
     * @return the status
     */
    public String getStatus() {
        return status;
    }

    /**
     * @param status the status to set
     */
    public void setStatus(String status) {
        this.status = status;
    }

    /**
     * @return the payType
     */
    public String getPayType() {
        return payType;
    }

    /**
     * @param payType the payType to set
     */
    public void setPayType(String payType) {
        this.payType = payType;
    }

    /**
     * @return the bizOrderId
     */
    public String getBizOrderId() {
        return bizOrderId;
    }

    /**
     * @param bizOrderId the bizOrderId to set
     */
    public void setBizOrderId(String bizOrderId) {
        this.bizOrderId = bizOrderId;
    }

    /**
     * @return the bizNo
     */
    public String getBizNo() {
        return bizNo;
    }

    /**
     * @param bizNo the bizNo to set
     */
    public void setBizNo(String bizNo) {
        this.bizNo = bizNo;
    }

    /**
     * @return the orderAmt
     */
    public Integer getOrderAmt() {
        return orderAmt;
    }

    /**
     * @param orderAmt the orderAmt to set
     */
    public void setOrderAmt(Integer orderAmt) {
        this.orderAmt = orderAmt;
    }

    /**
     * @return the reqTime
     */
    public Date getReqTime() {
        return reqTime;
    }

    /**
     * @param reqTime the reqTime to set
     */
    public void setReqTime(Date reqTime) {
        this.reqTime = reqTime;
    }

    /**
     * @return the cancelTime
     */
    public Date getCancelTime() {
        return cancelTime;
    }

    /**
     * @param cancelTime the cancelTime to set
     */
    public void setCancelTime(Date cancelTime) {
        this.cancelTime = cancelTime;
    }

    /**
     * @return the extraJson
     */
    public String getExtraJson() {
        return extraJson;
    }

    /**
     * @param extraJson the extraJson to set
     */
    public void setExtraJson(String extraJson) {
        this.extraJson = extraJson;
    }
}

==> dbservice-1.0.0-20141222.081448-10-sources.jar: com/xunlei/channel/db/pojo/ChannelAutoPayQuit.java <==
/**
 * 
 */
package com.xunlei.channel.db.pojo;

import java.util.Date;

/**
 * 渠道自动续费退订表
 * 
 * @author gonglijian
 */
public class ChannelAutoPayQuit extends AbstractBaseEntity {

    /**
	 * 
	 */
    private static final long serialVersionUID = -1190682736820312898L;
    private String            xunleiId;
    private String            userShow;
    private String            xunleiPayId;
    private String            phone;
    /**
     * 退订类型
     */
    private String            quitType;
    /**
     * 退订状态：W：等待;S:退订成功;F：退订失败
     */
    private String            status;

    private String            payType;
    private String            bizOrderId;
    private String            bizNo;
    private Integer           orderAmt;
    private Date              reqTime;
    private Date              cancelTime;
    private String            extraJson;

    /**
     * @return the xunleiId
     */
    public String getXunleiId() {
        return xunleiId;
    }

    /**
     * @param xunleiId the xunleiId to set
     */
    public void setXunleiId(String xunleiId) {
        this.xunleiId = xunleiId;
    }

    /**
     * @return the userShow
     */
    public String getUserShow() {
        return userShow;
    }

    /**
     * @param userShow the userShow to set
     */
    public void setUserShow(String userShow) {
        this.userShow = userShow;
    }

    /**
     * @return the xunleiPayId
     */
    public String getXunleiPayId() {
        return xunleiPayId;
    }

    /**
     * @param xunleiPayId the xunleiPayId to set
     */
    public void setXunleiPayId(String xunleiPayId) {
        this.xunleiPayId = xunleiPayId;
    }

    /**
     * @return the phone
     */
    public String getPhone() {
        return phone;
    }

    /**
     * @param phone the phone to set
     */
    public void setPhone(String phone) {
        this.phone = phone;
    }

    /**
     * @return the quitType
     */
    public String getQuitType() {
        return quitType;
    }

    /**
     * @param quitType the quitType to set
     */
    public void setQuitType(String quitType) {
        this.quitType = quitType;
    }

    /**
     * @return the status
     */
    public String getStatus() {
        return status;
    }

    /**
     * @param status the status to set
     */
    public void setStatus(String status) {
        this.status = status;
    }

    /**
     * @return the payType
     */
    public String getPayType() {
        return payType;
    }

    /**
     * @param payType the payType to set
     */
    public void setPayType(String payType) {
        this.payType = payType;
    }

    /**
     * @return the bizOrderId
     */
    public String getBizOrderId() {
        return bizOrderId;
    }

    /**
     * @param bizOrderId the bizOrderId to set
     */
    public void setBizOrderId(String bizOrderId) {
        this.bizOrderId = bizOrderId;
    }

    /**
     * @return the bizNo
     */
    public String getBizNo() {
        return bizNo;
    }

    /**
     * @param bizNo the bizNo to set
     */
    public void setBizNo(String bizNo) {
        this.bizNo = bizNo;
    }

    /**
     * @return the orderAmt
     */
    public Integer getOrderAmt() {
        return orderAmt;
    }

    /**
     * @param orderAmt the orderAmt to set
     */
    public void setOrderAmt(Integer orderAmt) {
        this.orderAmt = orderAmt;
    }

    /**
     * @return the reqTime
     */
    public Date getReqTime() {
        return reqTime;
    }

    /**
     * @param reqTime the reqTime to set
     */
    public void setReqTime(Date reqTime) {
        this.reqTime = reqTime;
    }

    /**
     * @return the cancelTime
     */
    public Date getCancelTime() {
        return cancelTime;
    }

    /**
     * @param cancelTime the cancelTime to set
     */
    public void setCancelTime(Date cancelTime) {
        this.cancelTime = cancelTime;
    }

    /**
     * @return the extraJson
     */
    public String getExtraJson() {
        return extraJson;
    }

    /**
     * @param extraJson the extraJson to set
     */
    public void setExtraJson(String extraJson) {
        this.extraJson = extraJson;
    }
}
